/**
* rh_killCounter.sqf 1.0.0
* Handles kill counting with ACE support.
*
* Parameter 0: broadcast results (boolean, default: true).
* Parameter 1: debug mode (boolean, default: false).
*
* You can access the current situation with the following
* global variable: rh_killCounter_STATUS
*
* Returned syntax: [previously killed, killer, total kills WEST, EAST, GUER, CIV]
*
* Author: Raunhofer
* Date: 02.02.2018
* License: MIT
**/

if (!isServer) exitWith {};

// Parameters.
rh_killCounter_BROADCAST = param [0, false, [false]];
rh_killCounter_DEBUG = param [1, false, [false]];

// Init the status variable.
rh_killCounter_STATUS = [objNull, objNull, 0, 0, 0, 0];

// Start listening for kills.
private _killedHandler = addMissionEventHandler ["EntityKilled", {
	// Init event params.
	params ["_killed", "_killer", "_instigator"];
	// ACE support.
	_instigator = _killed getVariable ["ace_medical_lastDamageSource", _instigator];
	if (isNull _instigator) then {_instigator = UAVControl vehicle _killer select 0};
	if (isNull _instigator) then {_instigator = _killer};
	// Set killer and killed.
	rh_killCounter_STATUS set [0, _killed];
	rh_killCounter_STATUS set [1, _instigator];
	// Update side kills.
	if (!isNull _instigator) then {
		private _killerSide = side _instigator;
		if (_killerSide == WEST) then {
			rh_killCounter_STATUS set [2, (rh_killCounter_STATUS select 2) + 1];
		};
		if (_killerSide == EAST) then {
			rh_killCounter_STATUS set [3, (rh_killCounter_STATUS select 3) + 1];
		};
		if (_killerSide == INDEPENDENT) then {
			rh_killCounter_STATUS set [4, (rh_killCounter_STATUS select 4) + 1];
		};
		if (_killerSide == CIVILIAN) then {
			rh_killCounter_STATUS set [5, (rh_killCounter_STATUS select 5) + 1];
		};
	};
	// Broadcast results.
	if (rh_killCounter_BROADCAST) then {
		publicVariable "rh_killCounter_STATUS";
	};
	// Debug.
	if (rh_killCounter_DEBUG) then {
		diag_log format ["rh_killCounter: %1", rh_killCounter_STATUS];
		hintSilent format ["rh_killCounter\n\nSTATUS\n%1", rh_killCounter_STATUS];
	};
}];

true
